import { useEffect, useState } from "react";

const Filter = ({ orders, setOrdersToShow }) => {
  const [all, setAll] = useState(true);
  const [received, setReceived] = useState(false);
  const [fulfilled, setFulfilled] = useState(false);
  const [cancelled, setCancelled] = useState(false);

  const RECEIVED = "RECEIVED";
  const FULFILLED = "FULFILLED";
  const CANCELLED = "CANCELLED";

  const reset = () => {
    setAll(true);
    setReceived(false);
    setFulfilled(false);
    setCancelled(false);
  };
  const receive = () => {
    setAll(false);
    setReceived(!received);
    if (received && !fulfilled && !cancelled) {
      setAll(true);
    }
  };
  const fulfill = () => {
    setAll(false);
    setFulfilled(!fulfilled);
    if (!received && fulfilled && !cancelled) {
      setAll(true);
    }
  };
  const cancel = () => {
    setAll(false);
    setCancelled(!cancelled);
    if (!received && !fulfilled && cancelled) {
      setAll(true);
    }
  };

  useEffect(() => {
    if (all) {
      setOrdersToShow(orders);
    } else {
      const newOrders = { allIds: [], byId: {} };
      orders.allIds.map((wareId) => {
        const order = orders.byId[wareId];
        switch (order.status) {
          case RECEIVED:
            if (all || received) {
              newOrders.allIds.push(wareId);
              newOrders.byId[wareId] = order;
            }
            break;
          case FULFILLED:
            if (all || fulfilled) {
              newOrders.allIds.push(wareId);
              newOrders.byId[wareId] = order;
            }
            break;
          case CANCELLED:
            if (all || cancelled) {
              newOrders.allIds.push(wareId);
              newOrders.byId[wareId] = order;
            }
            break;
          default:
            break;
        }
      });
  
      setOrdersToShow(newOrders);
    }
  }, [all, received, fulfilled, cancelled]);

  if (!orders.allIds.length) return null;

  return (
    <div className="filter">
      Filter: 
      <div className={`filter-all ${all ? "selected" : ""}`} onClick={reset}>
        All
      </div>
      <div
        className={`filter-rec ${received ? "selected" : ""}`}
        onClick={receive}
      >
        Received
      </div>
      <div
        className={`filter-ful ${fulfilled ? "selected" : ""}`}
        onClick={fulfill}
      >
        Fulfilled
      </div>
      <div
        className={`filter-can ${cancelled ? "selected" : ""}`}
        onClick={cancel}
      >
        Cancelled
      </div>
    </div>
  );
};;

export default Filter;
